﻿// Copyright (C) Microsoft Corporation. All Rights Reserved.
// This code released under the terms of the Microsoft Public License
// (Ms-PL, http://opensource.org/licenses/ms-pl.html).

using System.IO;
using System.Linq;
using System.Net.Mime;
using System.Text;
using Delay.Web.Helpers;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace AutomatedTests
{
    [TestClass]
    public class DataUriTests
    {
        private const string TestInput = "Hello world.";
        private const string TestResult = "data:text/plain;base64,SGVsbG8gd29ybGQu";

        [TestMethod]
        public void TestByteArray()
        {
            Assert.IsTrue(0 == string.CompareOrdinal(
                TestResult,
                DataUri.Write(Encoding.UTF8.GetBytes(TestInput), MediaTypeNames.Text.Plain).ToHtmlString()));
        }

        [TestMethod]
        public void TestIEnumerable()
        {
            Assert.IsTrue(0 == string.CompareOrdinal(
                TestResult,
                DataUri.Write(Encoding.UTF8.GetBytes(TestInput).ToList(), MediaTypeNames.Text.Plain).ToHtmlString()));
        }

        [TestMethod]
        public void TestStream()
        {
            using (var stream = new MemoryStream(Encoding.UTF8.GetBytes(TestInput)))
            {
                Assert.IsTrue(0 == string.CompareOrdinal(
                    TestResult,
                    DataUri.Write(stream, MediaTypeNames.Text.Plain).ToHtmlString()));
            }
        }

        [TestMethod]
        public void TestFile()
        {
            var fileName = Path.GetTempFileName();
            try
            {
                File.WriteAllText(fileName, TestInput);
                Assert.IsTrue(0 == string.CompareOrdinal(
                    TestResult,
                    DataUri.Write(fileName, MediaTypeNames.Text.Plain).ToHtmlString()));
            }
            finally
            {
                File.Delete(fileName);
            }
        }

        [TestMethod]
        public void TestFileWithInference()
        {
            var fileName = Path.GetTempFileName() + ".txt";
            try
            {
                File.WriteAllText(fileName, TestInput);
                Assert.IsTrue(0 == string.CompareOrdinal(
                    TestResult,
                    DataUri.Write(fileName).ToHtmlString()));
            }
            finally
            {
                File.Delete(fileName);
            }
        }
    }
}
